from unittest import TestCase

from holour import json_encode, json_decode
from holour.msg import ProgramState


class Test(TestCase):

    def test_program_state(self):
        program_state = ProgramState(ProgramState.START)
        program_state_string = json_encode(program_state)
        expected_string = '{"_type": "program_state", "program_state": "start"}'

        self.assertIs(type(program_state_string), str, f"Got: {type(program_state_string)}. Expected {str}")
        self.assertEqual(program_state_string, expected_string, f"Expected {expected_string}, got: {program_state_string}")

        program_string_decoded = json_decode(program_state_string)
        assert type(program_string_decoded) == ProgramState, f"Got: {type(program_string_decoded)}. Expected {ProgramState}"
        assert program_string_decoded == program_state, "The decoded object must be equal to the encoded"

    def test_program_state_equals(self):
        ps1 = ProgramState(ProgramState.START)
        ps2 = ProgramState(ProgramState.START)
        ps3 = ProgramState(ProgramState.PAUSE)

        assert ps1 == ps2
        assert ps1 != ps3
        assert ps1 != "not status"

    def test_program_state_repr(self):
        ps = ProgramState(ProgramState.START)
        expected, got = 'start', f'{ps}'

        assert expected in got, f"Expected {expected} in got: {got}"




from holour.msg.geometry import Vector3, Pose, Poses
from holour.msg.status import Status
from holour.msg.force_torque import ForceTorque
from holour.msg.script import Script, WaypointConfig
from holour.msg.task import Task
from holour.msg.product import Product
from holour.msg.process import Process
from holour.msg.assembly import AddProcess, MoveTask, CompleteTask, Destination, ConfirmNeeded, ConfirmTask, TaskStatus
from holour.msg.robot import ProgramState





class ProgramState:

    START = 'start'
    PAUSE = 'pause'
    STOP = 'stop'

    def __init__(self, program_state: str, _type: str = ''):
        assert program_state in (self.START, self.PAUSE, self.STOP)
        self._type = 'program_state'
        self.program_state = program_state

    def __eq__(self, other: object) -> bool:
        if isinstance(other, ProgramState):
            return other.program_state == self.program_state
        return False

    def __ne__(self, other: object) -> bool:
        return not self.__eq__(other)

    def __repr__(self):
        return f"<program_state={self.program_state}>"
